dml_with_smoother functionPost-estimation command to extract outcome weights for double ML run with an outcome smoother.
# S3 method for dml_with_smoother
get_outcome_weights(object, ..., all_reps = FALSE)If all_reps == FALSE: get_outcome_weights object
If all_reps == TRUE: additionally list omega_all_reps:
A list containing the outcome weights of each repetition.
An object of class dml_with_smoother, i.e. the result of running dml_with_smoother.
Pass potentially generic get_outcome_weights options.
If TRUE, outcomes weights of each repetitions passed. Default FALSE.
Knaus, M. C. (2024). Treatment effect estimators as weighted outcomes, https://arxiv.org/abs/2411.11559.